@@ -6,7 +6,8 @@ Caller = namedtuple('Caller', ['module', 'function', 'line_number'])
 
 def inspect_caller(offset: int = 0) -> Caller:
     stack = inspect.stack()[2 + offset]
-    return Caller(module=inspect.getmodule(stack.frame).__name__,
+    module = inspect.getmodule(stack.frame)
+    return Caller(module=module.__name__ if module is not None else '',
                     function=stack.function, line_number=stack.lineno)
 
 def format_elapsed_time(elapsed: float) -> str:
